Gevt est un Gestionnaire de Volontaires et de Tâches écrit en python pour faciliter la gestion d'événements impliquant
l'attribution de bénévoles (les volontaires) à l'éxécution de tâches.

GitHub repo: https://github.com/seb5g/gevt

Pypi: *pip install gevt*

    

